<?php

namespace app\models;

use Yii;
use yii\db\ActiveRecord;


/**
* @property int id
* @property string first_name
* @property string surname
* @property string patronymic
* @property string username
* @property string email
* @property string password
* @property string authKey
* @property int is_admin
 */

class User extends ActiveRecord implements \yii\web\IdentityInterface
{

    private static $users;


    /**
     * {@inheritdoc}
     */
    public static function findIdentity($id)
    {
        return User::findOne($id);
    }

    /**
     * {@inheritdoc}
     */
    public static function findIdentityByAccessToken($token, $type = null)
    {
        foreach (self::$users as $user) {
            if ($user['accessToken'] === $token) {
                return new static($user);
            }
        }

        return null;
    }

    /**
     * Finds user by username
     *
     * @param string $username
     * @return static|null
     */
    public static function findByUsername($username)
    {
    return static::findOne(['username'=>$username]);
    }

    /**
     * {@inheritdoc}
     */
    public function getId()
    {
        return $this->id;
    }

    /**
     * {@inheritdoc}
     */
    public function getAuthKey()
    {
       return $this->authKey;
    }

    /**
     * {@inheritdoc}
     */
    public function validateAuthKey($authKey)
    {
        return $this->authKey === $authKey;
    }

    public function rules()
    {
        return [
            [['is_admin'], 'integer'],
            [['created_at'], 'safe'],
            [['first_name', 'surname', 'patronymic', 'username', 'email', 'password', 'authKey'], 'string', 'max' => 256],
        ];
    }

    /**
     * Validates password
     *
     * @param string $password password to validate
     * @return bool if password provided is valid for current user
     */
    public function validatePassword($password)
    {
        return Yii::$app->security->validatePassword($password, $this->password);
    }

    public function HashPassword($password) {
        $this->password = Yii::$app->security->generatePasswordHash($password);
    }

    public static function tableName()
    {
        return ('users');
    }

}
